@@ -15,9 +15,7 @@
 #include <audio/soundlib.h>
 
 static void
-fatalError(message, arg)
-char           *message,
-               *arg;
+fatalError(const char *message, const char *arg)
 {
     fprintf(stderr, message, arg);
     fprintf(stderr, "\n");
@@ -25,10 +23,7 @@ char           *message,
 }
 
 static AuBool
-EventHandler(aud, ev, handler)
-AuServer       *aud;
-AuEvent        *ev;
-AuEventHandlerRec *handler;
+EventHandler(AuServer *aud, AuEvent *ev, AuEventHandlerRec *handler)
 {
     AuBool         *done = (AuBool *) handler->data;
     AuElementNotifyEvent *event = (AuElementNotifyEvent *) ev;
@@ -42,9 +37,7 @@ AuEventHandlerRec *handler;
 }
 
 int
-main(argc, argv)
-int             argc;
-char          **argv;
+main(int argc, char **argv)
 {
     AuServer       *aud;
     AuBucketID      bucket;
@@ -59,7 +52,7 @@ char          **argv;
     int             i;
 
     if (argc < 2)
-	fatalError("usage: loopBucket filename");
+	fatalError("usage: loopBucket filename", NULL);
 
     if (!(aud = AuOpenServer(NULL, 0, NULL, 0, NULL, NULL)))
 	exit(1);
@@ -79,10 +72,10 @@ char          **argv;
 	}
 
     if (device == AuNone)
-	fatalError("Couldn't find an output device");
+	fatalError("Couldn't find an output device", NULL);
 
     if (!(flow = AuCreateFlow(aud, NULL)))
-	fatalError("Couldn't create flow");
+	fatalError("Couldn't create flow", NULL);
 
     AuMakeChangeStateAction(&actions[0], AuStateStop, AuStateStart,
 			    AuReasonEOF, flow, AuElementAll, AuStateStart);
@@ -99,7 +92,7 @@ char          **argv;
     if (!(handler = AuRegisterEventHandler(aud, AuEventHandlerIDMask,
 					   0, flow, EventHandler,
 					   (AuPointer) &done)))
-	fatalError("Couldn't register event handler");
+	fatalError("Couldn't register event handler", NULL);
 
     AuStartFlow(aud, flow, NULL);
 
