@@ -44,9 +44,7 @@
 #include <audio/sound.h>
 
 static void
-fatalError(message, arg)
-char           *message,
-               *arg;
+fatalError(const char *message, const char *arg)
 {
     fprintf(stderr, message, arg);
     fprintf(stderr, "\n");
@@ -54,8 +52,7 @@ char           *message,
 }
 
 static char    *
-convertQuotes(str)
-char           *str;
+convertQuotes(char *str)
 {
     int             len = strlen(str) * 2 + 1;	/* more then enough for
 						 * string */
@@ -78,9 +75,7 @@ char           *str;
 }
 
 int
-main(argc, argv)
-int             argc;
-char          **argv;
+main(int argc, char **argv)
 {
     Sound           s;
     char           *p,
@@ -88,7 +83,7 @@ char          **argv;
     int             i;
 
     if (argc != 2)
-	fatalError("usage: soundtoh filename");
+	fatalError("usage: soundtoh filename", NULL);
 
     if (!(s = SoundOpenFileForReading(name)))
 	fatalError("Can't open file \"%s\"", name);
