@@ -46,17 +46,22 @@ without express or implied warranty.
  */
 
 void
-AuNextEvent (aud, dequeue, event)
-	register AuServer *aud;
-	AuBool dequeue;
-	register AuEvent *event;
+AuNextEvent (
+             AuServer *aud,
+             AuBool dequeue,
+             AuEvent *event
+             )
 {
-	register _AuQEvent *qelt;
+	_AuQEvent *qelt;
 	
 	_AuLockServer();
 	
-	if (aud->head == NULL)		/* block until event arrives */
-	    _AuReadEvents(aud);
+	if (aud->head == NULL) {		/* block until event arrives */
+	  _AuUnlockServer();
+	  _AuReadEvents(aud);	/* will use it's own lock to prevent
+				   deadlock situations */
+	  _AuLockServer();
+	}
 	qelt = aud->head;
 	*event = qelt->event;
 
