@@ -25,24 +25,23 @@
 #include "Alibint.h"
 
 /* JET - a default server to try if all else fails */
-#define DEFAULT_AUSERVER "tcp/localhost:8000"
+#define DEFAULT_AUSERVER ":0"
 
 #ifdef AU_NOT_STDC_ENV
-extern _AuConst char *getenv();
+extern const char *getenv();
 #endif
 
-_AuConst char *
-AuServerName (name)
-    _AuConst char *name;
+const char *
+AuServerName (const char *name)
 {
     if (name && name[0])
 	return name;
 
-    name = (_AuConst char *) getenv ("AUDIOSERVER");
+    name = (const char *) getenv ("AUDIOSERVER");
     if (name)
 	return name;
 
-    name = (_AuConst char *) getenv ("DISPLAY");
+    name = (const char *) getenv ("DISPLAY");
     if (name)
 	return name;
 
