@@ -19,7 +19,8 @@
  * WHETHER IN AN ACTION IN CONTRACT, TORT OR NEGLIGENCE, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  * 
- * $NCDId: @(#)audiolib.h,v 1.65 1994/09/02 17:54:22 greg Exp $
+ * $Id: audiolib.h 226 2006-08-31 00:46:14Z jon $
+ * $NCDId: @(#)audiolib.h,v 1.67 1995/12/28 19:46:49 greg Exp $
  * 
  * <audio/audiolib.h>
  * 
@@ -34,9 +35,13 @@
  *				    VERSION				     *
  *****************************************************************************/
 
-#define AudioLibraryVersion	2
 
 
+#define AudioLibraryVersionMajor        2
+#define AudioLibraryVersionMinor        3
+#define AudioLibraryVersionTeeny        0
+
+#define AudioLibraryVersion             AudioLibraryVersionMajor
 
 /*****************************************************************************
  *			    GET NEEDED HEADER FILES			     *
@@ -88,7 +93,6 @@ typedef char   *AuPointer;
 typedef void   *AuPointer;
 #endif
 
-#if NeedFunctionPrototypes
 /* struct pre-declarations */
 struct _AuErrorEvent;
 struct _AuServer;
@@ -96,7 +100,6 @@ struct _AuEventHandlerRec;
 struct _AuEventEnqHandlerRec;
 struct _AuSyncHandlerRec;
 union _AuEvent;
-#endif
 
 typedef struct _AuString
 {
@@ -116,26 +119,20 @@ AU_MACRO_SUFFIX
 
 typedef
 AuBool(*AuErrorHandler) (
-#if NeedFunctionPrototypes
 			 struct _AuServer *,	/* server */
 			 struct _AuErrorEvent *	/* error_event */
-#endif
 );
 
 typedef
 AuBool(*AuIOErrorHandler) (
-#if NeedFunctionPrototypes
 			   struct _AuServer *	/* server */
-#endif
 );
 
 typedef
 AuBool(*AuEventHandlerCallback) (
-#if NeedFunctionPrototypes
 				 struct _AuServer *,	/* server */
 				 union _AuEvent *,	/* event */
 				 struct _AuEventHandlerRec *	/* who invoked */
-#endif
 );
 
 #define AuEventHandlerTypeMask		(1L << 0)
@@ -157,11 +154,9 @@ typedef struct _AuEventHandlerRec
 
 typedef void
 (*AuSyncHandlerCallback) (
-#if NeedFunctionPrototypes
 			  struct _AuServer *,		/* server */
 			  struct _AuSyncHandlerRec *,	/* who called me */
 			  AuPointer			/* private data */
-#endif
 			  );
 
 typedef struct _AuSyncHandlerRec
@@ -179,12 +174,10 @@ typedef struct _AuSyncHandlerRec
 typedef void
 (*AuEventEnqHandlerCallback)
 (
-#if NeedFunctionPrototypes
     struct _AuServer *,			/* server */
     struct _AuEventEnqHandlerRec *,	/* who called me */
     union _AuEvent *,			/* event */
     AuPointer				/* private data */
-#endif
 );
 
 typedef struct _AuEventEnqHandlerRec
@@ -1020,27 +1013,23 @@ _AUFUNCPROTOBEGIN
  * AuServerName - this routine returns the that the library will use to
  * locate the audio server.
  */
-extern _AuConst char *
+extern const char * AUCDECL
 AuServerName(
-#if NeedFunctionPrototypes
-	     _AuConst char *			/* servername */
-#endif
+	     const char *			/* servername */
 );
 
 /*
  * AuOpenServer - this routine is used to open a connection to an audio
  * server.
  */
-extern AuServer *
+extern AuServer * AUCDECL
 AuOpenServer(
-#if NeedFunctionPrototypes
-	     _AuConst char *,			/* servername */
+	     const char *,			/* servername */
 	     int,				/* num_authproto */
-	     _AuConst char *,			/* authproto */
+	     const char *,			/* authproto */
 	     int,				/* num_authdata */
-	     _AuConst char *,			/* authdata */
+	     const char *,			/* authdata */
 	     char **				/* server_message */
-#endif
 );
 
 
@@ -1048,11 +1037,9 @@ AuOpenServer(
  * AuCloseServer - this routine is used to close a connection to an audio
  * server when it is no AuInt32er needed.
  */
-extern void
+extern void AUCDECL
 AuCloseServer(
-#if NeedFunctionPrototypes
 	      AuServer *			/* server */
-#endif
 );
 
 
@@ -1061,12 +1048,10 @@ AuCloseServer(
  * be called when this connection sees an error that is not being intercepted
  * by the library.
  */
-extern          AuErrorHandler
+extern          AuErrorHandler AUCDECL
 AuSetErrorHandler(
-#if NeedFunctionPrototypes
 		  AuServer *,			/* server */
 		  AuErrorHandler		/* handler */
-#endif
 );
 
 
@@ -1075,35 +1060,29 @@ AuSetErrorHandler(
  * should be called when the connection to the server has unexpectedly been
  * broken.
  */
-extern          AuIOErrorHandler
+extern          AuIOErrorHandler AUCDECL
 AuSetIOErrorHandler(
-#if NeedFunctionPrototypes
 		    AuServer *,			/* server */
 		    AuIOErrorHandler		/* handler */
-#endif
 );
 
 
 /*
  * AuFlush - this routine flushes any queued packets down to the server.
  */
-extern void
+extern void AUCDECL
 AuFlush(
-#if NeedFunctionPrototypes
 	AuServer *				/* server */
-#endif
 );
 
 
 /*
  * AuSync - this routine forces a round trip to the server
  */
-extern void
+extern void AUCDECL
 AuSync(
-#if NeedFunctionPrototypes
        AuServer *,				/* server */
        AuBool					/* discard_queued_events */
-#endif
 );
 
 
@@ -1111,12 +1090,10 @@ AuSync(
  * AuSynchronize - this routine instructs the library to operate
  * synchronously, which may be easier for some applications to deal with.
  */
-extern          AuBool
+extern          AuBool AUCDECL
 AuSynchronize(
-#if NeedFunctionPrototypes
 	      AuServer *,			/* server */
 	      AuBool				/* enablesync */
-#endif
 );
 
 
@@ -1124,14 +1101,12 @@ AuSynchronize(
  * AuGetErrorText - this routine is used to translate error codes into
  * English strings for printing.
  */
-extern void
+extern void AUCDECL
 AuGetErrorText(
-#if NeedFunctionPrototypes
 	       AuServer *,			/* server */
 	       int,				/* code */
 	       char *,				/* buffer_return */
 	       int				/* length */
-#endif
 );
 
 
@@ -1139,16 +1114,14 @@ AuGetErrorText(
  * AuGetErrorDatabaseText - this routine is used to lookup strings for error
  * messages.
  */
-extern void
+extern void AUCDECL
 AuGetErrorDatabaseText(
-#if NeedFunctionPrototypes
 		       AuServer *,		/* server */
-		       _AuConst char *,		/* name */
-		       _AuConst char *,		/* message */
-		       _AuConst char *,		/* default_string */
+		       const char *,		/* name */
+		       const char *,		/* message */
+		       const char *,		/* default_string */
 		       char *,			/* buffer_return */
 		       int			/* length */
-#endif
 );
 
 
@@ -1157,13 +1130,11 @@ AuGetErrorDatabaseText(
  * AuSetCloseDownMode - this routine instructs the server to save any objects
  * created by this client even if it shuts down.
  */
-extern void
+extern void AUCDECL
 AuSetCloseDownMode(
-#if NeedFunctionPrototypes
 		   AuServer *,			/* server */
 		   int,				/* mode */
 		   AuStatus *			/* RETURN_status */
-#endif
 );
 
 
@@ -1171,36 +1142,30 @@ AuSetCloseDownMode(
  * AuGetCloseDownMode - this routine returns the current close-down mode for
  * this client.
  */
-extern int
+extern int AUCDECL
 AuGetCloseDownMode(
-#if NeedFunctionPrototypes
 		   AuServer *,			/* server */
 		   AuStatus *			/* RETURN_status */
-#endif
 );
 
 /*
  * AuGetServerTime - this routine returns the current server time
  */
-extern AuTime
+extern AuTime AUCDECL
 AuGetServerTime(
-#if NeedFunctionPrototypes
 		   AuServer *,			/* server */
 		   AuStatus *			/* RETURN_status */
-#endif
 );
 
 /*
  * AuKillClient - this routine forces the client that created the specified
  * resource to close down, regardless of its close down mode.
  */
-extern void
+extern void AUCDECL
 AuKillClient(
-#if NeedFunctionPrototypes
 	     AuServer *,			/* server */
 	     AuID,				/* resource */
 	     AuStatus *				/* RETURN_status */
-#endif
 );
 
 
@@ -1210,15 +1175,13 @@ AuKillClient(
  * for the fields in changable_mask returned by AuGetDeviceAttributes or the
  * setup information.
  */
-extern void
+extern void AUCDECL
 AuSetDeviceAttributes(
-#if NeedFunctionPrototypes
 		      AuServer *,		/* server */
 		      AuDeviceID,		/* resource */
 		      AuMask,			/* value_mask */
 		      AuDeviceAttributes *,	/* attr */
 		      AuStatus *		/* RETURN_status */
-#endif
 );
 
 
@@ -1226,28 +1189,24 @@ AuSetDeviceAttributes(
  * AuGetDeviceAttributes - this routine is used to get device attributes
  * (which are also provided by the server at connection setup).
  */
-extern AuDeviceAttributes *
+extern AuDeviceAttributes * AUCDECL
 AuGetDeviceAttributes(
-#if NeedFunctionPrototypes
 		      AuServer *,		/* server */
 		      AuDeviceID,		/* resource */
 		      AuStatus *		/* RETURN_status */
-#endif
 );
 
 
 /*
  * AuListDevices - this routine is used to query the devices
  */
-extern AuDeviceAttributes *
+extern AuDeviceAttributes * AUCDECL
 AuListDevices(
-#if NeedFunctionPrototypes
 	      AuServer *,			/* server */
 	      AuMask,				/* value_mask */
 	      AuDeviceAttributes *,		/* attr */
 	      int *,				/* RETURN_ndevices */
 	      AuStatus *			/* RETURN_status */
-#endif
 );
 
 
@@ -1255,13 +1214,11 @@ AuListDevices(
  * AuFreeDeviceAttributes - this routine is used to free storage returned by
  * calls to AuGetDeviceAttributes.
  */
-extern void
+extern void AUCDECL
 AuFreeDeviceAttributes(
-#if NeedFunctionPrototypes
 		       AuServer *,		/* server */
 		       int,			/* num_attr */
 		       AuDeviceAttributes *	/* attr */
-#endif
 );
 
 
@@ -1269,13 +1226,11 @@ AuFreeDeviceAttributes(
  * AuGetBucketAttributes - this routine is used to get bucket attributes
  * (which are also provided by the server at connection setup).
  */
-extern AuBucketAttributes *
+extern AuBucketAttributes * AUCDECL
 AuGetBucketAttributes(
-#if NeedFunctionPrototypes
 		      AuServer *,		/* server */
 		      AuBucketID,		/* resource */
 		      AuStatus *		/* RETURN_status */
-#endif
 );
 
 
@@ -1283,15 +1238,13 @@ AuGetBucketAttributes(
  * AuListBuckets - this routine is used to query the buffers for a given
  * client, all retained clients, or all known buffers.
  */
-extern AuBucketAttributes *
+extern AuBucketAttributes * AUCDECL
 AuListBuckets(
-#if NeedFunctionPrototypes
 	      AuServer *,			/* server */
 	      AuMask,				/* value_mask */
 	      AuBucketAttributes *,		/* attr */
 	      int *,				/* RETURN_nbuckets */
 	      AuStatus *			/* RETURN_status */
-#endif
 );
 
 
@@ -1299,22 +1252,19 @@ AuListBuckets(
  * AuFreeBucketAttributes - this routine is used to free storage returned by
  * calls to AuGetBucketAttributes.
  */
-extern void
+extern void AUCDECL
 AuFreeBucketAttributes(
-#if NeedFunctionPrototypes
 		       AuServer *,		/* server */
 		       int,			/* num_attr */
 		       AuBucketAttributes *	/* attr */
-#endif
 );
 
 /*
  * AuCreateBucket - this routine is used to create new buckets (buffers,
  * radios, wave form generators)
  */
-extern          AuBucketID
+extern          AuBucketID AUCDECL
 AuCreateBucket(
-#if NeedFunctionPrototypes
 	       AuServer *,			/* server */
 	       AuUint32,			/* format */
 	       AuUint32,			/* num tracks */
@@ -1323,7 +1273,6 @@ AuCreateBucket(
 	       AuUint32,			/* num_samples */
 	       AuString *,			/* description */
 	       AuStatus *			/* RETURN_status */
-#endif
 );
 
 
@@ -1331,13 +1280,11 @@ AuCreateBucket(
  * AuDestroyBucket - this routine is used to destroy a bucket once it is no
  * AuInt32er being used.
  */
-extern void
+extern void AUCDECL
 AuDestroyBucket(
-#if NeedFunctionPrototypes
 		AuServer *,			/* server */
 		AuBucketID,			/* bucket */
 		AuStatus *			/* RETURN_status */
-#endif
 );
 
 
@@ -1346,12 +1293,10 @@ AuDestroyBucket(
  * describes how audio data gets from one or more inputs to one or more
  * outputs.
  */
-extern          AuFlowID
+extern          AuFlowID AUCDECL
 AuCreateFlow(
-#if NeedFunctionPrototypes
 	     AuServer *,			/* server */
 	     AuStatus *				/* RETURN_status */
-#endif
 );
 
 
@@ -1359,13 +1304,11 @@ AuCreateFlow(
  * AuDestroyFlow - this routine is used to destroy a Flow object once it is
  * no AuInt32er needed.
  */
-extern void
+extern void AUCDECL
 AuDestroyFlow(
-#if NeedFunctionPrototypes
 	      AuServer *,			/* server */
 	      AuFlowID,				/* flow */
 	      AuStatus *			/* RETURN_status */
-#endif
 );
 
 
@@ -1373,14 +1316,12 @@ AuDestroyFlow(
  * AuGetFlowAttributes - this routine is used to find out what the state of
  * the flow is at any given time.
  */
-extern          AuBool
+extern          AuBool AUCDECL
 AuGetFlowAttributes(
-#if NeedFunctionPrototypes
 		    AuServer *,			/* server */
 		    int,			/* num_attrs */
 		    AuFlowAttributes *,		/* attrs */
 		    AuStatus *			/* RETURN_status */
-#endif
 );
 
 
@@ -1390,16 +1331,14 @@ AuGetFlowAttributes(
  * API will keep a list of scratch flows to use in sending audio data over
  * the wire.
  */
-extern void
+extern void AUCDECL
 AuSetElements(
-#if NeedFunctionPrototypes
 	      AuServer *,			/* server */
 	      AuFlowID,				/* flow id */
 	      AuBool,				/* clocked */
 	      int,				/* num_elements */
 	      AuElement *,			/* elements */
 	      AuStatus *			/* RETURN_status */
-#endif
 );
 
 
@@ -1407,15 +1346,13 @@ AuSetElements(
  * AuGetElements - this routine is used to return the element topology that
  * was set in the AuCreateElements.
  */
-extern AuElement *
+extern AuElement * AUCDECL
 AuGetElements(
-#if NeedFunctionPrototypes
 	      AuServer *,			/* server */
 	      AuFlowID,				/* flow id */
 	      AuBool *,				/* RETURN_clocked */
 	      int *,				/* RETURN_num_elements */
 	      AuStatus *			/* RETURN_status */
-#endif
 );
 
 
@@ -1423,13 +1360,11 @@ AuGetElements(
  * AuFreeElements - this routine is used to free the results returned from a
  * call to AuGetElements.
  */
-extern void
+extern void AUCDECL
 AuFreeElements(
-#if NeedFunctionPrototypes
 	       AuServer *,			/* server */
 	       int,				/* num_elements */
 	       AuElement *			/* listofelements */
-#endif
 );
 
 
@@ -1437,14 +1372,12 @@ AuFreeElements(
  * AuGetElementStates - this routine is used to get the state of various
  * elements within a flow.
  */
-extern AuElementState *
+extern AuElementState * AUCDECL
 AuGetElementStates(
-#if NeedFunctionPrototypes
 		   AuServer *,			/* server */
 		   int *,			/* INOUT_num_states */
 		   AuElementState *,		/* states */
 		   AuStatus *			/* RETURN_status */
-#endif
 );
 
 
@@ -1452,13 +1385,11 @@ AuGetElementStates(
  * AuFreeElementStates - this routine is used to free the results returned
  * from a call to AuGetElementStates.
  */
-extern void
+extern void AUCDECL
 AuFreeElementStates(
-#if NeedFunctionPrototypes
 		    AuServer *,			/* server */
 		    int,			/* num_elements */
 		    AuElementState *		/* list of element states */
-#endif
 );
 
 
@@ -1466,14 +1397,12 @@ AuFreeElementStates(
  * AuSetElementStates - this routine is used to set the state of various
  * elements within a flow.
  */
-extern void
+extern void AUCDECL
 AuSetElementStates(
-#if NeedFunctionPrototypes
 		   AuServer *,			/* server */
 		   int,				/* num_states */
 		   AuElementState *,		/* states */
 		   AuStatus *			/* RETURN_status */
-#endif
 );
 
 
@@ -1481,14 +1410,12 @@ AuSetElementStates(
  * AuSetElementParameters - this routine is used to change parameters of
  * elements within a flow.  Changes in element types is not permitted.
  */
-extern void
+extern void AUCDECL
 AuSetElementParameters(
-#if NeedFunctionPrototypes
 		       AuServer *,		/* server */
 		       int,			/* num_changes */
 		       AuElementParameters *,	/* changes */
 		       AuStatus *		/* RETURN_status */
-#endif
 );
 
 
@@ -1497,9 +1424,8 @@ AuSetElementParameters(
  * AuWriteElement - this routine is used to send audio data to an
  * ImportClient element in a flow.
  */
-extern void
+extern void AUCDECL
 AuWriteElement(
-#if NeedFunctionPrototypes
 	       AuServer *,			/* server */
 	       AuFlowID,			/* flow */
 	       int,				/* element */
@@ -1507,7 +1433,6 @@ AuWriteElement(
 	       AuPointer,			/* data */
 	       AuBool,				/* end of data flag */
 	       AuStatus *			/* RETURN_status */
-#endif
 );
 
 
@@ -1515,16 +1440,14 @@ AuWriteElement(
  * AuReadElement - this routine is used to get audio data from an
  * ExportClient element in a flow.
  */
-extern AuUint32
+extern AuUint32 AUCDECL
 AuReadElement(
-#if NeedFunctionPrototypes
 	      AuServer *,			/* server */
 	      AuFlowID,				/* flow */
 	      int,				/* element */
 	      AuUint32,			/* num_bytes */
 	      AuPointer,			/* data */
 	      int *				/* RETURN_status */
-#endif
 );
 
 #define AuEventsQueued _AuEventsQueued
@@ -1533,12 +1456,10 @@ AuReadElement(
  * AuEventsQueued - this routine is used to see if there are any events
  * waiting to be read.
  */
-extern int
+extern int AUCDECL
 AuEventsQueued(
-#if NeedFunctionPrototypes
 	       AuServer *,			/* server */
 	       int				/* AuEventsQueued_mode */
-#endif
 );
 
 
@@ -1547,22 +1468,18 @@ AuEventsQueued(
  * events that match a client-supplied predicate.  If the predicate returns
  * AuTrue for an event, that event is returned to the caller.
  */
-extern          AuBool
+extern          AuBool AUCDECL
 AuScanEvents(
-#if NeedFunctionPrototypes
 	     AuServer *,			/* server */
 	     int,				/* AuEventsQueued_mode */
 	     AuBool,				/* dequeue_match */
 	     AuBool(*) (			/* clientpredicate */
-#if NeedNestedPrototypes
 			AuServer *,		/* server */
 			AuEvent *,		/* eventtocheck */
 			AuPointer		/* clientdata */
-#endif
 			),
 	     AuPointer,				/* clientdata */
 	     AuEvent *				/* RETURN_event */
-#endif
 );
 
 
@@ -1570,15 +1487,13 @@ AuScanEvents(
  * AuScanForTypedEvent - this is a convenience routine that calls
  * AuScanEvents with a predicate that looks for the specified event type.
  */
-extern          AuBool
+extern          AuBool AUCDECL
 AuScanForTypedEvent(
-#if NeedFunctionPrototypes
 		    AuServer *,			/* server */
 		    int,			/* AuEventsQueued_mode */
 		    AuBool,			/* dequeue */
 		    int,			/* eventtype */
 		    AuEvent *			/* RETURN_event */
-#endif
 );
 
 
@@ -1586,13 +1501,11 @@ AuScanForTypedEvent(
  * AuNextEvent - this routine is used to read a queued event.  If there is no
  * event available, it will block until one arrives.
  */
-extern void
+extern void AUCDECL
 AuNextEvent(
-#if NeedFunctionPrototypes
 	    AuServer *,				/* server */
 	    AuBool,				/* dequeue */
 	    AuEvent *				/* RETURN_event */
-#endif
 );
 
 
@@ -1604,13 +1517,11 @@ AuNextEvent(
  * skip (0 means the head of the queue, AuServerQLength() means the end of
  * the queue).
  */
-extern          AuBool
+extern          AuBool AUCDECL
 AuRequeueEvent(
-#if NeedFunctionPrototypes
 	       AuServer *,			/* server */
 	       AuEvent *,			/* event */
 	       int				/* skip */
-#endif
 );
 
 
@@ -1618,18 +1529,15 @@ AuRequeueEvent(
  * AuIDOfEvent - this routine returns the Flow, Bucket, or Device id from an
  * event so that it can be used to dispatch the event to the proper handler.
  */
-extern          AuID
+extern          AuID AUCDECL
 AuIDOfEvent(
-#if NeedFunctionPrototypes
 	    AuEvent *				/* RETURN_event */
-#endif
 );
 
 
-extern void AuFree (
-#if NeedFunctionPrototypes
+extern void  AUCDECL
+AuFree (
 		    AuPointer
-#endif
 );
 
 /*****************************************************************************
@@ -1668,6 +1576,11 @@ _AUFUNCPROTOEND
  * that errors in the open procedure are handled.
  */
 
+#if defined(WIN32) && (!defined(_OPENSVR_C_) && !defined(__CYGWIN__))
+#define AuDefaultErrorHandler	(*AuDefaultErrorHandler_p)
+#define AuDefaultIOErrorHandler	(*AuDefaultIOErrorHandler_p)
+#endif /* WIN32 && !_OPENSVR_C_ */
+
 extern AuErrorHandler AuDefaultErrorHandler;
 extern AuIOErrorHandler AuDefaultIOErrorHandler;
 
