@@ -1,4 +1,4 @@
-/* $Id: nameaddr.c 185 2006-08-26 21:10:33Z jon $ */
+/* $Id: nameaddr.c 246 2007-05-12 01:03:53Z jon $ */
 /* $NCDId: @(#)nameaddr.c,v 1.2 1994/05/02 17:42:06 greg Exp $ */
 /* $XConsortium: nameaddr.c,v 1.5 91/09/12 13:41:04 rws Exp $ */
 /*	nameaddr.c - included by Astreams.c			*/
@@ -343,7 +343,7 @@ fprintf(stderr, "Trying to get the binding address for service %s on %s\n",
 #endif
 		if( strcmp(netconfigp->nc_netid, "starlan") == 0 )
 		{
-			register char *from, *to;
+			char *from, *to;
 			int	i, len;
 
 			from = to = netbufp->buf;
@@ -717,7 +717,7 @@ ConvertAddress(
                int len
                )
 {
-    register i;
+    i;
     char	*ptr;
     int     l, rl; 
     struct nd_hostservlist *nd_hostservlist;
