@@ -28,15 +28,131 @@
 
 #define _SOUND_C_
 
+#include "config.h"
+
 #include	<stdio.h>
-#include 	<malloc.h>
+
+#if defined(HAVE_STDLIB_H)
+# include <stdlib.h> 
+#endif
+
+#if defined(HAVE_MALLOC_H)
+# include <malloc.h>
+#endif
+
 #include	<audio/Aos.h>
 #include	<audio/audio.h>
 #include	<audio/sound.h>
 
+/* JET  - 7/20/2002
+   Due to issues with cygwin's inability to import an array of structs
+   for a DLL, we will put the declaration of SoundFileInfo[] here (from
+   sound.h) and provide a function that will return the appropriate
+   struct based on an index supplied.
+   Since apps shouldn't have been accessing this struct directly anyway,
+   there should be no effect on applications adhering to this rule.
+*/
+
+#ifndef hpux
+typedef void   *(*_pFunc) ();
+#define _VOIDP_ (_pFunc)
+#else						/* hpux */
+#define _VOIDP_
+#endif						/* hpux */
+
+#define _oo SoundDataFormatBit
+
+static int      sndToSound(), soundToSnd(),
+                vocToSound(), soundToVoc(),
+                waveToSound(), soundToWave(),
+                aiffToSound(), soundToAiff(),
+                svxToSound(), soundToSvx();
+
+
+/* This order must match the _SoundFileFormatsID enum defined in sound.h */
+static _SoundConst SoundInfo _SoundFileInfo[] =
+{
+    "Sun/NeXT", "snd", "snd au",
+    (_oo(AuFormatULAW8) | _oo(AuFormatLinearUnsigned8) |
+     _oo(AuFormatLinearSigned16MSB)),
+    _VOIDP_ SndOpenFileForReading, _VOIDP_ SndOpenFileForWriting,
+    SndReadFile, SndWriteFile, SndCloseFile, SndRewindFile,
+    SndSeekFile, SndTellFile, SndFlushFile, sndToSound, soundToSnd,
+
+    "Creative Labs VOC", "voc", "voc",
+    _oo(AuFormatLinearUnsigned8),
+    _VOIDP_ VocOpenFileForReading, _VOIDP_ VocOpenFileForWriting,
+    VocReadFile, VocWriteFile, VocCloseFile, VocRewindFile,
+    VocSeekFile, VocTellFile, VocFlushFile, vocToSound, soundToVoc,
+
+    "Microsoft WAVE", "wave", "wav",
+    (_oo(AuFormatLinearUnsigned8) | _oo(AuFormatLinearSigned16LSB)),
+    _VOIDP_ WaveOpenFileForReading, _VOIDP_ WaveOpenFileForWriting,
+    WaveReadFile, WaveWriteFile, WaveCloseFile, WaveRewindFile,
+    WaveSeekFile, WaveTellFile, WaveFlushFile, waveToSound, soundToWave,
+
+    "AIFF", "aiff", "aiff",
+    (_oo(AuFormatLinearSigned8) | _oo(AuFormatLinearSigned16MSB)),
+    _VOIDP_ AiffOpenFileForReading, _VOIDP_ AiffOpenFileForWriting,
+    AiffReadFile, AiffWriteFile, AiffCloseFile, AiffRewindFile,
+    AiffSeekFile, AiffTellFile, AiffFlushFile, aiffToSound, soundToAiff,
+
+    "Amiga IFF/8SVX", "8svx", "iff",
+    _oo(AuFormatLinearSigned8),
+    _VOIDP_ SvxOpenFileForReading, _VOIDP_ SvxOpenFileForWriting,
+    SvxReadFile, SvxWriteFile, SvxCloseFile, SvxRewindFile,
+    SvxSeekFile, SvxTellFile, SvxFlushFile, svxToSound, soundToSvx,
+};
+
+#undef _oo
+#undef _VOIDP_
+
+const int SoundNumFileFormats =
+(sizeof(_SoundFileInfo) / sizeof(_SoundFileInfo[0]));
+
+char *SoundFileFormatString(Sound s)
+{
+  return(_SoundFileInfo[SoundFileFormat(s)].string);
+}
+
+int SoundValidDataFormat(int _f, int _d)
+{
+  return((_SoundFileInfo[_f].dataFormats & SoundDataFormatBit(_d) ? 1 : 0));
+}
+
+char *SoundFileFormatToString(int _i)
+{
+  return(_SoundFileInfo[_i].string);
+}
+
+char *SoundFileFormatToAbbrev(int _i)
+{
+  return(_SoundFileInfo[_i].abbrev);
+}
+
+char *SoundFileFormatToSuffixes(int _i)
+{
+  return(_SoundFileInfo[_i].suffixes);
+}
+
+SoundFileInfoProc SoundFileGetProc(int format, int proc)
+{
+  switch (proc)
+    {
+    case SoundFileInfoProcTo:
+      return(_SoundFileInfo[format].toSound);
+      break;
+    case SoundFileInfoProcFrom:
+      return(_SoundFileInfo[format].fromSound);
+      break;
+    default:
+      return(NULL);
+    }
+}
+   
+
 static int
-SndToSoundFormat(fmt)
-int             fmt;
+SndToSoundFormat(int fmt)
 {
     switch (fmt)
     {
@@ -52,8 +168,7 @@ int             fmt;
 }
 
 static int
-SoundToSndFormat(fmt)
-int             fmt;
+SoundToSndFormat(int fmt)
 {
     switch (fmt)
     {
@@ -69,8 +184,7 @@ int             fmt;
 }
 
 static int
-sndToSound(s)
-Sound           s;
+sndToSound(Sound s)
 {
     SndInfo        *p = (SndInfo *)s->formatInfo;
     SndHeader      *h = &p->h;
@@ -92,8 +206,7 @@ Sound           s;
 }
 
 static int
-soundToSnd(s)
-Sound           s;
+soundToSnd(Sound s)
 {
     SndInfo        *si;
 
@@ -113,8 +226,7 @@ Sound           s;
 }
 
 static int
-vocToSound(s)
-Sound           s;
+vocToSound(Sound s)
 {
     VocInfo        *p = (VocInfo *)s->formatInfo;
 
@@ -129,8 +241,7 @@ Sound           s;
 }
 
 static int
-soundToVoc(s)
-Sound           s;
+soundToVoc(Sound s)
 {
     VocInfo        *vi;
 
@@ -146,8 +257,7 @@ Sound           s;
 }
 
 static int
-WaveToSoundFormat(wi)
-WaveInfo       *wi;
+WaveToSoundFormat(WaveInfo *wi)
 {
     if (wi->bitsPerSample == 8)
 	return AuFormatLinearUnsigned8;
@@ -159,8 +269,7 @@ WaveInfo       *wi;
 }
 
 static int
-waveToSound(s)
-Sound           s;
+waveToSound(Sound s)
 {
     WaveInfo       *wi = (WaveInfo *)s->formatInfo;
 
@@ -175,8 +284,7 @@ Sound           s;
 }
 
 static int
-soundToWave(s)
-Sound           s;
+soundToWave(Sound s)
 {
     WaveInfo       *wi;
 
@@ -193,8 +301,7 @@ Sound           s;
 }
 
 static int
-AiffToSoundFormat(ai)
-AiffInfo       *ai;
+AiffToSoundFormat(AiffInfo *ai)
 {
     if (ai->bitsPerSample == 8)
 	return AuFormatLinearSigned8;
@@ -206,8 +313,7 @@ AiffInfo       *ai;
 }
 
 static int
-aiffToSound(s)
-Sound           s;
+aiffToSound(Sound s)
 {
     AiffInfo       *ai = (AiffInfo *)s->formatInfo;
 
@@ -222,8 +328,7 @@ Sound           s;
 }
 
 static int
-soundToAiff(s)
-Sound           s;
+soundToAiff(Sound s)
 {
     AiffInfo       *ai;
 
@@ -240,8 +345,7 @@ Sound           s;
 }
 
 static int
-svxToSound(s)
-Sound           s;
+svxToSound(Sound s)
 {
     SvxInfo        *si = (SvxInfo *)s->formatInfo;
 
@@ -256,8 +360,7 @@ Sound           s;
 }
 
 static int
-soundToSvx(s)
-Sound           s;
+soundToSvx(Sound s)
 {
     SvxInfo        *si;
 
@@ -272,8 +375,7 @@ Sound           s;
 }
 
 Sound
-SoundOpenFileForReading(name)
-_SoundConst char *name;
+SoundOpenFileForReading(const char *name)
 {
     Sound           s;
     int             i;
@@ -284,9 +386,9 @@ _SoundConst char *name;
     SoundComment(s) = NULL;
 
     for (i = 0; i < SoundNumFileFormats; i++)
-	if ((s->formatInfo = (SoundFileInfo[i].openFileForReading) (name)))
+	if ((s->formatInfo = (_SoundFileInfo[i].openFileForReading) (name)))
 	{
-	    if (!(SoundFileInfo[i].toSound) (s))
+	    if (!(_SoundFileInfo[i].toSound) (s))
 	    {
 		SoundCloseFile(s);
 		return NULL;
@@ -304,12 +406,13 @@ _SoundConst char *name;
 }
 
 Sound
-SoundOpenFileForWriting(name, s)
-_SoundConst char *name;
-Sound           s;
+SoundOpenFileForWriting(
+                        const char *name,
+                        Sound           s
+                        )
 {
     if (SoundFileFormat(s) != SoundFileFormatNone &&
-	(SoundFileInfo[SoundFileFormat(s)].openFileForWriting) (name,
+	(_SoundFileInfo[SoundFileFormat(s)].openFileForWriting) (name,
 							     s->formatInfo))
     {
         SoundNumSamples(s) = 0;
@@ -320,23 +423,25 @@ Sound           s;
 }
 
 int
-SoundReadFile(p, n, s)
-char           *p;
-int             n;
-Sound           s;
+SoundReadFile(
+              char           *p,
+              int             n,
+              Sound           s
+              )
 {
-    return (SoundFileInfo[SoundFileFormat(s)].readFile) (p, n, s->formatInfo);
+    return (_SoundFileInfo[SoundFileFormat(s)].readFile) (p, n, s->formatInfo);
 }
 
 int
-SoundWriteFile(p, n, s)
-char           *p;
-int             n;
-Sound           s;
+SoundWriteFile(
+               char           *p,
+               int             n,
+               Sound           s
+               )
 {
     int             num;
 
-    num = (SoundFileInfo[SoundFileFormat(s)].writeFile) (p, n, s->formatInfo);
+    num = (_SoundFileInfo[SoundFileFormat(s)].writeFile) (p, n, s->formatInfo);
     if (SoundNumSamples(s) != SoundUnknownNumSamples)
         SoundNumSamples(s) += (num / SoundNumTracks(s) /
                                SoundBytesPerSample(s));
@@ -346,37 +451,34 @@ Sound           s;
 }
 
 int
-SoundRewindFile(s)
-Sound           s;
+SoundRewindFile(Sound s)
 {
-    return (SoundFileInfo[SoundFileFormat(s)].rewindFile) (s->formatInfo);
+    return (_SoundFileInfo[SoundFileFormat(s)].rewindFile) (s->formatInfo);
 }
 
 int
-SoundSeekFile(n, s)
-int             n;
-Sound           s;
+SoundSeekFile(
+              int             n,
+              Sound           s
+              )
 {
-    return (SoundFileInfo[SoundFileFormat(s)].seekFile) (n, s->formatInfo);
+    return (_SoundFileInfo[SoundFileFormat(s)].seekFile) (n, s->formatInfo);
 }
 
 int
-SoundTellFile(s)
-Sound           s;
+SoundTellFile(Sound s)
 {
-    return (SoundFileInfo[SoundFileFormat(s)].tellFile) (s->formatInfo);
+    return (_SoundFileInfo[SoundFileFormat(s)].tellFile) (s->formatInfo);
 }
 
 int
-SoundFlushFile(s)
-Sound           s;
+SoundFlushFile(Sound s)
 {
-    return (SoundFileInfo[SoundFileFormat(s)].flushFile) (s->formatInfo);
+    return (_SoundFileInfo[SoundFileFormat(s)].flushFile) (s->formatInfo);
 }
 
 int
-SoundCloseFile(s)
-Sound           s;
+SoundCloseFile(Sound s)
 {
     int             status = 0;
 
@@ -384,7 +486,7 @@ Sound           s;
 	return status;
 
     if (s->formatInfo)
-	status = (SoundFileInfo[SoundFileFormat(s)].closeFile) (s->formatInfo);
+	status = (_SoundFileInfo[SoundFileFormat(s)].closeFile) (s->formatInfo);
     else if (SoundComment(s))
 	free(SoundComment(s));
 
@@ -393,13 +495,14 @@ Sound           s;
 }
 
 Sound
-SoundCreate(fileFormat, dataFormat, numTracks, sampleRate, numSamples, comment)
-int             fileFormat,
-                dataFormat,
-                numTracks,
-                sampleRate,
-                numSamples;
-_SoundConst char *comment;
+SoundCreate(
+            int fileFormat,
+            int dataFormat,
+            int numTracks,
+            int sampleRate,
+            int numSamples,
+            const char *comment
+            )
 {
     Sound           s;
 
@@ -447,7 +550,7 @@ _SoundConst char *comment;
 
     if (SoundFileFormat(s) != SoundFileFormatNone)
 	if (!SoundValidateDataFormat(s) ||
-	    !(SoundFileInfo[SoundFileFormat(s)].fromSound) (s))
+	    !(_SoundFileInfo[SoundFileFormat(s)].fromSound) (s))
 	{
 	    free(SoundComment(s));
 	    free(s);
@@ -458,26 +561,24 @@ _SoundConst char *comment;
 }
 
 int
-SoundStringToFileFormat(s)
-_SoundConst char *s;
+SoundStringToFileFormat(const char *s)
 {
     int             i;
 
     for (i = 0; i < SoundNumFileFormats; i++)
-	if (!strcasecmp(s, SoundFileInfo[i].string))
+	if (!strcasecmp(s, _SoundFileInfo[i].string))
 	    break;
 
     return i == SoundNumFileFormats ? -1 : i;
 }
 
 int
-SoundAbbrevToFileFormat(s)
-_SoundConst char *s;
+SoundAbbrevToFileFormat(const char *s)
 {
     int             i;
 
     for (i = 0; i < SoundNumFileFormats; i++)
-	if (!strcasecmp(s, SoundFileInfo[i].abbrev))
+	if (!strcasecmp(s, _SoundFileInfo[i].abbrev))
 	    break;
 
     return i == SoundNumFileFormats ? -1 : i;
