@@ -1,4 +1,4 @@
-/* $Id: auvoxware.c 270 2007-11-22 23:53:23Z steve_mcintyre $ */
+/* $Id: auvoxware.c 288 2013-08-11 21:28:33Z auerswald $ */
 
 /*
    SCCS: @(#) auvoxware.c 11.4 95/04/14 
@@ -1326,6 +1326,8 @@ disableProcessFlow(void)
 {
 #ifndef sco
     int rate;
+
+    processFlowEnabled = AuFalse;
 #endif /* sco */
 
     if (NasConfig.DoDebug) {
@@ -1358,7 +1360,9 @@ disableProcessFlow(void)
         oneMoreTick();
 #endif
 
+#ifdef sco
         processFlowEnabled = AuFalse;
+#endif
 
         if (relinquish_device)
             closeDevice();
@@ -1441,7 +1445,8 @@ writePhysicalOutputsMono(void)
     {
         char tempbuf[80];
 
-        sprintf(tempbuf, "\nwriteMono buf: %d size: %d\n", buf, bufSize);
+        snprintf(tempbuf, sizeof tempbuf, "\nwriteMono buf: %d size: %d\n",
+                 buf, bufSize);
         write(dspout, tempbuf, strlen(tempbuf));
         write(dspout, buf, bufSize);
     }
@@ -1520,7 +1525,8 @@ writePhysicalOutputsStereo(void)
     {
         char tempbuf[80];
 
-        sprintf(tempbuf, "\nwriteStereo buf: %d size: %d\n", buf, bufSize);
+        snprintf(tempbuf, sizeof tempbuf, "\nwriteStereo buf: %d size: %d\n",
+                 buf, bufSize);
         write(dspout, tempbuf, strlen(tempbuf));
         write(dspout, buf, bufSize);
     }
@@ -1582,7 +1588,7 @@ readPhysicalInputs(void)
 #ifdef DEBUGDSPIN
     {
         char tempbuf[80];
-        sprintf(tempbuf, "\nreadInputs buf: %d size: %d\n",
+        snprintf(tempbuf, sizeof tempbuf, "\nreadInputs buf: %d size: %d\n",
                 stereoInputDevice->minibuf,
                 stereoInputDevice->bytesPerSample * auMinibufSamples);
         write(dspin, tempbuf, strlen(tempbuf));
