@@ -2,7 +2,7 @@
  * aulog.c - provide a global logging function - varargs based for verbosity
  *           and debugging.
  *
- * $Id: aulog.c 272 2008-01-30 19:56:26Z auerswald $
+ * $Id: aulog.c 288 2013-08-11 21:28:33Z auerswald $
  *
  * Jon Trulson 9/11/99
  */
@@ -29,7 +29,7 @@ osLogMsg(const char *fmt, ...)
 
     va_start(ap, fmt);
 
-    (void) vsprintf(buf, fmt, ap);
+    (void) vsnprintf(buf, sizeof buf, fmt, ap);
 
     va_end(ap);
 
@@ -37,7 +37,7 @@ osLogMsg(const char *fmt, ...)
 
     if (NasConfig.DoDaemon) {   /* daemons use syslog */
         openlog("nas", LOG_PID, LOG_DAEMON);
-        syslog(LOG_DEBUG, buf);
+        syslog(LOG_DEBUG, "%s", buf);
         closelog();
     } else {
         errfd = stderr;
