@@ -19,7 +19,7 @@
  * WHETHER IN AN ACTION IN CONTRACT, TORT OR NEGLIGENCE, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  * 
- * $Id: utils.c 246 2007-05-12 01:03:53Z jon $
+ * $Id: utils.c 287 2013-08-09 17:19:13Z auerswald $
  * $NCDId: @(#)utils.c,v 1.8 1996/04/24 17:16:15 greg Exp $
  */
 /***********************************************************
@@ -50,6 +50,9 @@ SOFTWARE.
 
 #include <audio/audio.h>
 #include <audio/Aos.h>
+#include <audio/Aproto.h>
+#include <errno.h>
+#include <limits.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include "nasconf.h"
@@ -298,6 +301,26 @@ ProcessCommandLine(int argc, char *argv[])
 
     for (i = 1; i < argc; i++) {
         if (argv[i][0] == ':') {
+            char *check;
+            long display_value;
+            errno = 0;
+            display_value = strtol(argv[i]+1, &check, 10);
+            if (errno) {
+                Error("Unable to parse display number");
+                continue;
+            }
+            if (check[0] != '\0') {
+                fprintf(stderr, "Listen port offset must be a number.\n");
+                continue;
+            }
+            if (display_value > USHRT_MAX - AU_DEFAULT_TCP_PORT) {
+                fprintf(stderr, "Ignoring too big listen port offset.\n");
+                continue;
+            }
+            if (display_value < 0) {
+                fprintf(stderr, "Ignoring negative listen port offset.\n");
+                continue;
+            }
             display = argv[i];
             display++;
         } else if (strcmp(argv[i], "-aa") == 0)
